==> jc-1.4.0.tar.gz: java__5fcup/action__5fproduction.h <==
// public class java_cup.action_production

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95be63b9ba65a467 java__5fcup_action__5fproduction
// @dep_class 5d7079afb0198954 java__5fcup_production

// header file dependencies
// @dep_header java__5fcup_production

#include "java__5fcup/production.h"

#ifndef _JC_java__5fcup_action__5fproduction_H_
#define _JC_java__5fcup_action__5fproduction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_non__5fterminal$object;
struct _jc_java__5fcup_production$object;

// Typedefs
typedef struct _jc_java__5fcup_action__5fproduction$sub_refs	_jc_java__5fcup_action__5fproduction$sub_refs;
typedef struct _jc_java__5fcup_action__5fproduction$sub_nonrefs	_jc_java__5fcup_action__5fproduction$sub_nonrefs;
typedef struct _jc_java__5fcup_action__5fproduction$refs	_jc_java__5fcup_action__5fproduction$refs;
typedef struct _jc_java__5fcup_action__5fproduction$nonrefs	_jc_java__5fcup_action__5fproduction$nonrefs;
typedef struct _jc_java__5fcup_action__5fproduction$object	_jc_java__5fcup_action__5fproduction$object;

typedef const struct _jc_java__5fcup_action__5fproduction$vmethods	_jc_java__5fcup_action__5fproduction$vmethods;
typedef const struct _jc_java__5fcup_action__5fproduction$vtable	_jc_java__5fcup_action__5fproduction$vtable;
typedef const struct _jc_java__5fcup_action__5fproduction$vtype	_jc_java__5fcup_action__5fproduction$vtype;

// Constructors
extern void _jc_java__5fcup_action__5fproduction$method$_init$13c8df9e747db3e5(_jc_env *, struct _jc_java__5fcup_action__5fproduction$object *, struct _jc_java__5fcup_production$object *, struct _jc_java__5fcup_non__5fterminal$object *, struct _jc_object_array *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java__5fcup_production$object *_jc_java__5fcup_action__5fproduction$method$base__5fproduction$feb1a70d4802549e(_jc_env *, struct _jc_java__5fcup_action__5fproduction$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_action__5fproduction$method_info$base__5fproduction$feb1a70d4802549e;

// Virtual methods structure
struct _jc_java__5fcup_action__5fproduction$vmethods {
	struct _jc_java__5fcup_production$object	*(*base__5fproduction$feb1a70d4802549e)(_jc_env *, struct _jc_java__5fcup_action__5fproduction$object *);
};

// Vtable
struct _jc_java__5fcup_action__5fproduction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_production$vmethods	java__5fcup_production;
	_jc_java__5fcup_action__5fproduction$vmethods	java__5fcup_action__5fproduction;
};

// Vtype
struct _jc_java__5fcup_action__5fproduction$vtype {
	_jc_type			type;
	_jc_java__5fcup_action__5fproduction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_action__5fproduction$sub_refs {
	struct _jc_java__5fcup_production$object	*__5fbase__5fproduction;
};

// Reference instance fields (object)
struct _jc_java__5fcup_action__5fproduction$refs {
    _jc_java__5fcup_action__5fproduction$sub_refs	java__5fcup_action__5fproduction;
    _jc_java__5fcup_production$sub_refs	java__5fcup_production;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_action__5fproduction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_action__5fproduction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_production$sub_nonrefs	java__5fcup_production;
    _jc_java__5fcup_action__5fproduction$sub_nonrefs	java__5fcup_action__5fproduction;
};

// Object instance structure
struct _jc_java__5fcup_action__5fproduction$object {
	_jc_java__5fcup_action__5fproduction$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_action__5fproduction$vtype	*vtype;
	_jc_java__5fcup_action__5fproduction$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_action__5fproduction$vtype _jc_java__5fcup_action__5fproduction$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_action__5fproduction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_action__5fproduction$class_object;

#endif	/* _JC_java__5fcup_action__5fproduction_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/action__5fproduction.h <==
// public class java_cup.action_production

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95be63b9ba65a467 java__5fcup_action__5fproduction
// @dep_class 5d7079afb0198954 java__5fcup_production

// header file dependencies
// @dep_header java__5fcup_production

#include "java__5fcup/production.h"

#ifndef _JC_java__5fcup_action__5fproduction_H_
#define _JC_java__5fcup_action__5fproduction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_non__5fterminal$object;
struct _jc_java__5fcup_production$object;

// Typedefs
typedef struct _jc_java__5fcup_action__5fproduction$sub_refs	_jc_java__5fcup_action__5fproduction$sub_refs;
typedef struct _jc_java__5fcup_action__5fproduction$sub_nonrefs	_jc_java__5fcup_action__5fproduction$sub_nonrefs;
typedef struct _jc_java__5fcup_action__5fproduction$refs	_jc_java__5fcup_action__5fproduction$refs;
typedef struct _jc_java__5fcup_action__5fproduction$nonrefs	_jc_java__5fcup_action__5fproduction$nonrefs;
typedef struct _jc_java__5fcup_action__5fproduction$object	_jc_java__5fcup_action__5fproduction$object;

typedef const struct _jc_java__5fcup_action__5fproduction$vmethods	_jc_java__5fcup_action__5fproduction$vmethods;
typedef const struct _jc_java__5fcup_action__5fproduction$vtable	_jc_java__5fcup_action__5fproduction$vtable;
typedef const struct _jc_java__5fcup_action__5fproduction$vtype	_jc_java__5fcup_action__5fproduction$vtype;

// Constructors
extern void _jc_java__5fcup_action__5fproduction$method$_init$13c8df9e747db3e5(_jc_env *, struct _jc_java__5fcup_action__5fproduction$object *, struct _jc_java__5fcup_production$object *, struct _jc_java__5fcup_non__5fterminal$object *, struct _jc_object_array *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java__5fcup_production$object *_jc_java__5fcup_action__5fproduction$method$base__5fproduction$feb1a70d4802549e(_jc_env *, struct _jc_java__5fcup_action__5fproduction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_action__5fproduction$method_info$base__5fproduction$feb1a70d4802549e;

// Virtual methods structure
struct _jc_java__5fcup_action__5fproduction$vmethods {
	struct _jc_java__5fcup_production$object	*(*base__5fproduction$feb1a70d4802549e)(_jc_env *, struct _jc_java__5fcup_action__5fproduction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_action__5fproduction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_production$vmethods	java__5fcup_production;
	_jc_java__5fcup_action__5fproduction$vmethods	java__5fcup_action__5fproduction;
};

// Vtype
struct _jc_java__5fcup_action__5fproduction$vtype {
	_jc_type			type;
	_jc_java__5fcup_action__5fproduction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_action__5fproduction$sub_refs {
	struct _jc_java__5fcup_production$object	*__5fbase__5fproduction;
};

// Reference instance fields (object)
struct _jc_java__5fcup_action__5fproduction$refs {
    _jc_java__5fcup_action__5fproduction$sub_refs	java__5fcup_action__5fproduction;
    _jc_java__5fcup_production$sub_refs	java__5fcup_production;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_action__5fproduction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_action__5fproduction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_production$sub_nonrefs	java__5fcup_production;
    _jc_java__5fcup_action__5fproduction$sub_nonrefs	java__5fcup_action__5fproduction;
};

// Object instance structure
struct _jc_java__5fcup_action__5fproduction$object {
	_jc_java__5fcup_action__5fproduction$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_action__5fproduction$vtype	*vtype;
	_jc_java__5fcup_action__5fproduction$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_action__5fproduction$vtype _jc_java__5fcup_action__5fproduction$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_action__5fproduction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_action__5fproduction$class_object;

#endif	/* _JC_java__5fcup_action__5fproduction_H_ */
